Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(261)

Unified Diff: runtime/vm/dart_api_message.h

Issue 14142008: Add support for more typed data types on native ports (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Addressed review comments Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/dart_api_message.h
diff --git a/runtime/vm/dart_api_message.h b/runtime/vm/dart_api_message.h
index d215ab01f2a1884d65399249baded3e3e9f52693..3ad8fb96bb19177feaba1dc4ce0089f2114ec8cf 100644
--- a/runtime/vm/dart_api_message.h
+++ b/runtime/vm/dart_api_message.h
@@ -88,8 +88,9 @@ class ApiMessageReader : public BaseReader {
Dart_CObject* AllocateDartCObjectDouble(double value);
// Allocates a Dart_CObject object for string data.
Dart_CObject* AllocateDartCObjectString(intptr_t length);
- // Allocates a C Dart_CObject object for byte data.
- Dart_CObject* AllocateDartCObjectUint8Array(intptr_t length);
+ // Allocates a C Dart_CObject object for a typed data.
+ Dart_CObject* AllocateDartCObjectTypedData(
+ Dart_CObject::TypedDataType type, intptr_t length);
// Allocates a C array of Dart_CObject objects.
Dart_CObject* AllocateDartCObjectArray(intptr_t length);
// Allocates a Dart_CObject_Internal object with the specified type.

Powered by Google App Engine
This is Rietveld 408576698